



ncdump -h "http://oos.soest.hawaii.edu/thredds/dodsC/hioos/model/atm/ncep_pac/NCEP_Pacific_Atmospheric_Model_best.ncd"
IF %ERRORLEVEL% NEQ 0 exit 1
ncdump -h "http://oos.soest.hawaii.edu/thredds/dodsC/usgs_dem_10m_tinian"
IF %ERRORLEVEL% NEQ 0 exit 1
exit 0
